/*
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <folly/dynamic.h>
#include <folly/portability/GTest.h>

TEST(dynamic, arrayCtor) {
  auto a = folly::dynamic::array(123, "hello", nullptr);

  ASSERT_TRUE(a.isArray());
  ASSERT_EQ(a.size(), 3);
  EXPECT_EQ(a[0], 123);
  EXPECT_EQ(a[1], "hello");
  EXPECT_TRUE(a[2].isNull());
}
